==> tao_iching-7.x-1.1.tar.gz: tao_iching/templates/tao-iching-form.tpl.php <==

<div class='iching_content'>
<?php
// dpm($form, $name = NULL);
print drupal_render_children($form);
?>
</div> <!-- END iching_content -->

<div class="iching_container">

<div class="intro_blurb">
This program uses the three coins method to produce hexagram lines.<br>
The applicable changing lines are obtained through Master Yin's rules.<br>
</div>

<div class="intro_blurb">
Keep in mind that as long as the algorithm can actually reach each and every
possible combination of hexagrams and changing lines, it doesn't really matter what the
probability is that each symbol can appear if you believe that a supreme Force is responsible for influencing the results.
</div>

<div class="creditcontainer_toggle_wrapper">
<a href="#0" id="creditcontainer_toggle">Credits</a>
</div>

<div id="creditcontainer" style="display:none;">
<div class="creditdiv">
This application was inspired entirely by the I-Ching Android app authored by Digital Illusion which can be found here:<br>
<a href="https://play.google.com/store/apps/details?id=org.digitalillusion.droid.iching&hl=en"target="_new">https://play.google.com/store/apps/details?id=org.digitalillusion.droid.iching&hl=en</a>
</div>
<div class="creditdiv">
All the contents available to this application were found on the net.
In particular the most complete and freely available sources are:<br>
</div>
<div class="creditdiv">
<a href="http://wengu.tartarie.com/wg/wengu.php?l=Yijing"target="_new">http://wengu.tartarie.com/wg/wengu.php?l=Yijing</a><br>
<a href="http://www.ichingonline.net/instruction.php"target="_new">http://www.ichingonline.net/instruction.php</a><br>
<a href="http://www.onlineclarity.co.uk/learn/consult/mml.php"target="_new">http://www.onlineclarity.co.uk/learn/consult/mml.php</a><br><br>
</div>
</div>

</div> <!-- END iching_container -->

==> tao_iching-7.x-1.4.tar.gz: tao_iching/templates/tao-iching-form.tpl.php <==
<div class='iching_content'>
<?php
$formOutput = drupal_render_children($form);
echo $formOutput;
?>
</div> <!-- END iching_content -->
<div class="iching_container">

<div class="intro_blurb">
<a href="/statistics">Top Ten Hexagrams</a>.<br>
This program uses the three coins method to produce hexagram lines.<br>
The applicable changing lines are obtained through Master Yin's rules.<br>
Toss the coins 6 times to obtain the reading, or get an <a href="/result/instant">instant reading</a>.

</div>

<div class="intro_blurb">
Keep in mind that as long as the algorithm can actually reach each and every
possible combination of hexagrams and changing lines, it doesn't really matter what the
probability is that each symbol can appear, if you believe that a higher power is responsible for influencing the results.
</div>

<div class="creditcontainer_toggle_wrapper">
<a href="#0" id="creditcontainer_toggle">Credits</a>
</div>

<div id="creditcontainer" style="display:none;">
<div class="creditdiv">
This application was inspired entirely by the I-Ching Android app authored by Digital Illusion which can be found here:<br>
<a href="https://play.google.com/store/apps/details?id=org.digitalillusion.droid.iching&hl=en"target="_new">https://play.google.com/store/apps/details?id=org.digitalillusion.droid.iching&hl=en</a>
</div>
<div class="creditdiv">
All the contents available to this application were found on the net.
In particular the most complete and freely available sources are:<br>
</div>
<div class="creditdiv">
<a href="http://wengu.tartarie.com/wg/wengu.php?l=Yijing"target="_new">http://wengu.tartarie.com/wg/wengu.php?l=Yijing</a><br>
<a href="http://www.ichingonline.net/instruction.php"target="_new">http://www.ichingonline.net/instruction.php</a><br>
<a href="http://www.onlineclarity.co.uk/learn/consult/mml.php"target="_new">http://www.onlineclarity.co.uk/learn/consult/mml.php</a><br><br>
</div>
</div>

</div> <!-- END iching_container -->
